@@ -1,5 +1,5 @@
 from checkio_client.api import get_mission_info
-from checkio_client.utils.code import code_for_file, init_code_file
+from checkio_client.utils.code import code_for_file, init_code_file, gen_filename
 from checkio_client.settings import conf
 
 import os
@@ -10,22 +10,18 @@ def main(args):
     if args.out and args.filename:
         raise ValueError('out and filename can not be used together')
 
-    mission = args.mission[0]
-    filename = args.filename
-    if not filename:
-        filename = (
-            mission.replace('-', '_') + '.' +
-            conf.default_domain_data['extension']
-        )
-
-
     if not args.out:
         print('Requesting...')
 
+    mission = args.mission[0]
     data = get_mission_info(mission)
     code = data['code']
     description = data['description']
 
+    filename = args.filename
+    if not filename:
+        filename = gen_filename(mission, data['stationName'])
+
     output = code_for_file(mission, code, 
         None if args.without_info else description)
 
@@ -33,6 +29,5 @@ def main(args):
         print(output)
         return
 
-
     init_code_file(filename, output)
     print('Done')
\ No newline at end of file
